pub struct BivarCommitment { /* private fields */ }Expand description
A commitment to a symmetric bivariate polynomial.
This commitment allows verification of values from a BivarPoly without
revealing the polynomial itself. It is used in distributed key generation
to publicly verify shares.
Example
use threshold_pairing::poly::BivarPoly;
let mut rng = rand::thread_rng();
let bi_poly = BivarPoly::random(2, &mut rng);
let commitment = bi_poly.commitment();
// The commitment has the same degree as the polynomial
assert_eq!(bi_poly.degree(), commitment.degree());
// Extract a row commitment
let row_commit = commitment.row(1u64);Implementations
Sourceimpl BivarCommitment
impl BivarCommitment
Sourcepub fn degree(&self) -> usize
pub fn degree(&self) -> usize
Returns the polynomial’s degree: It is the same in both variables.
Sourcepub fn evaluate<T: IntoScalar>(&self, x: T, y: T) -> G1Projective
pub fn evaluate<T: IntoScalar>(&self, x: T, y: T) -> G1Projective
Returns the commitment’s value at the point (x, y).
Sourcepub fn row<T: IntoScalar>(&self, x: T) -> Commitment
pub fn row<T: IntoScalar>(&self, x: T) -> Commitment
Returns the x-th row, as a commitment to a univariate polynomial.