pub struct BivarPoly { /* private fields */ }Expand description
A symmetric bivariate polynomial in the prime field.
This can be used for Verifiable Secret Sharing and Distributed Key Generation. See the module documentation for details.
A bivariate polynomial f(x, y) is symmetric if f(x, y) = f(y, x) for all x and y.
This property is essential for distributed key generation protocols.
Example
use threshold_pairing::poly::BivarPoly;
let mut rng = rand::thread_rng();
let bi_poly = BivarPoly::random(2, &mut rng);
// The polynomial is symmetric
let val_xy = bi_poly.evaluate(3u64, 5u64);
let val_yx = bi_poly.evaluate(5u64, 3u64);
assert_eq!(val_xy, val_yx);
// Extract a row as a univariate polynomial
let row = bi_poly.row(1u64);
assert_eq!(row.degree(), bi_poly.degree());
// Get the public commitment
let commitment = bi_poly.commitment();Security
The polynomial coefficients are zeroized on drop to prevent secret leakage.
Implementations
Sourceimpl BivarPoly
impl BivarPoly
Sourcepub fn random<R: RngCore>(degree: usize, rng: &mut R) -> Self
pub fn random<R: RngCore>(degree: usize, rng: &mut R) -> Self
Creates a random polynomial.
Panics
Panics if the degree is too high for the coefficients to fit into a Vec.
Sourcepub fn try_random<R: RngCore>(degree: usize, rng: &mut R) -> Result<Self>
pub fn try_random<R: RngCore>(degree: usize, rng: &mut R) -> Result<Self>
Creates a random polynomial.
Sourcepub fn degree(&self) -> usize
pub fn degree(&self) -> usize
Returns the polynomial’s degree; which is the same in both variables.
Sourcepub fn evaluate<T: IntoScalar>(&self, x: T, y: T) -> Scalar
pub fn evaluate<T: IntoScalar>(&self, x: T, y: T) -> Scalar
Returns the polynomial’s value at the point (x, y).
Sourcepub fn row<T: IntoScalar>(&self, x: T) -> Poly
pub fn row<T: IntoScalar>(&self, x: T) -> Poly
Returns the x-th row, as a univariate polynomial.
Sourcepub fn commitment(&self) -> BivarCommitment
pub fn commitment(&self) -> BivarCommitment
Returns the corresponding commitment. That information can be shared publicly.