Poly

Struct Poly 

pub struct Poly { /* private fields */ }
A univariate polynomial in the prime field.

Polynomials are used for secret sharing in threshold cryptography. A polynomial of degree t can be used to create n shares such that any t + 1 shares can reconstruct the secret (the polynomial’s value at 0).

Example

use threshold_pairing::poly::Poly;

// Create a random polynomial of degree 2
let mut rng = rand::thread_rng();
let poly = Poly::random(2, &mut rng);

// Evaluate the polynomial at different points
let y1 = poly.evaluate(1u64);
let y2 = poly.evaluate(2u64);

// Get the corresponding public commitment
let commitment = poly.commitment();
assert_eq!(poly.degree(), commitment.degree());

Security

The polynomial coefficients are zeroized on drop to prevent secret leakage.

Implementations

Source

impl Poly

pub fn random<R: RngCore>(degree: usize, rng: &mut R) -> Self

Creates a random polynomial.

Panics

Panics if the degree is too large for the coefficients to fit into a Vec.

pub fn try_random<R: RngCore>(degree: usize, rng: &mut R) -> Result<Self>

Creates a random polynomial. This constructor is identical to the Poly::random() constructor in every way except that this constructor will return an Err where try_random would return an error.

pub fn zero() -> Self

Returns the polynomial with constant value 0.

pub fn is_zero(&self) -> bool

Returns true if the polynomial is the constant value 0.

pub fn one() -> Self

Returns the polynomial with constant value 1.

pub fn constant(c: Scalar) -> Self

Returns the polynomial with constant value c.

pub fn identity() -> Self

Returns the identity function, i.e. the polynomial “x”.

pub fn monomial(degree: usize) -> Self

Returns the (monic) monomial: x.pow(degree).

pub fn interpolate<T, U, I>(samples_repr: I) -> Self
where I: IntoIterator<Item = (T, U)>, T: IntoScalar, U: IntoScalar,

Returns the unique polynomial f of degree samples.len() - 1 with the given values (x, f(x)).

pub fn degree(&self) -> usize

Returns the degree.

pub fn evaluate<T: IntoScalar>(&self, i: T) -> Scalar

Returns the value at the point i.

pub fn commitment(&self) -> Commitment

Returns the corresponding commitment.