Module serde_impl

Module serde_impl 

Serialization and deserialization implementations for group and field elements.

Structs

FieldWrap
A wrapper type to facilitate serialization and deserialization of field elements.
SerdeSecret
SerdeSecret is a wrapper struct for serializing and deserializing secret keys. Due to security concerns serialize shouldn’t be implemented for secret keys to avoid accidental leakage.