pub struct SerdeSecret<T>(pub T);Expand description
SerdeSecret is a wrapper struct for serializing and deserializing secret keys. Due to security
concerns serialize shouldn’t be implemented for secret keys to avoid accidental leakage.
Whenever this struct is used the integrity of security boundaries should be checked carefully.
Tuple Fields
0: TImplementations
Sourceimpl<T> SerdeSecret<T>
impl<T> SerdeSecret<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the actual secret from the wrapper