SecretKeySet

Struct SecretKeySet 

pub struct SecretKeySet { /* private fields */ }
A secret key and an associated set of secret key shares.

Implementations

Source

impl SecretKeySet

pub fn random<R: Rng>(threshold: usize, rng: &mut R) -> Self

Creates a set of secret key shares, where any threshold + 1 of them can collaboratively sign and decrypt. This constructor is identical to SecretKeySet::try_random in every way except that this constructor panics if the other returns an error.

Panics

Panics if the threshold is too large for the coefficients to fit into a Vec. For fallible construction, use SecretKeySet::try_random instead.

Example
use threshold_pairing::SecretKeySet;

let mut rng = rand::thread_rng();
let sk_set = SecretKeySet::random(2, &mut rng);

// Get shares for participants
let share_0 = sk_set.secret_key_share(0usize).expect("valid index");
let share_1 = sk_set.secret_key_share(1usize).expect("valid index");
pub fn try_random<R: Rng>(threshold: usize, rng: &mut R) -> Result<Self>

Creates a set of secret key shares, where any threshold + 1 of them can collaboratively sign and decrypt. This constructor is identical to SecretKeySet::random in every way except that this constructor returns an Err where random would panic.

Errors

Returns Error::DegreeTooHigh if the threshold is too large for the coefficients to fit into a Vec.

pub fn threshold(&self) -> usize

Returns the threshold t: any set of t + 1 signature shares can be combined into a full signature.

pub fn secret_key_share<T: TryIntoScalarSafe>( &self, i: T, ) -> Result<SecretKeyShare>

Returns the i-th secret key share.

Errors

Returns Error::IndexMapsToZero if i maps to the zero scalar after the internal index + 1 offset (e.g. -1i32). This prevents a caller from accidentally retrieving the master secret key through an out-of-range signed index.

pub fn public_keys(&self) -> PublicKeySet

Returns the corresponding public key set. That information can be shared publicly.