SecretKeyShare

Struct SecretKeyShare 

pub struct SecretKeyShare(/* private fields */);
A secret key share.

Serde integration

SecretKeyShare implements Deserialize but not Serialize to avoid accidental serialization in insecure contexts. To enable both use the ::serde_impl::SerdeSecret wrapper which implements both Deserialize and Serialize.

Implementations

Source

impl SecretKeyShare

pub fn from_mut(s: &mut Scalar) -> Self

Creates a new SecretKeyShare from a mutable reference to a field element.

Security

The source scalar is zeroized after copying to prevent secret leakage.

pub fn public_key_share(&self) -> PublicKeyShare

Returns the matching public key share.

pub fn sign_g2<H: Into<G2Affine>>(&self, hash: H) -> SignatureShare

Signs the given element of G2.

pub fn sign<M: AsRef<[u8]>>(&self, msg: M) -> SignatureShare

Signs the given message.

pub fn decrypt_share(&self, ct: &Ciphertext) -> Option<DecryptionShare>

Returns a decryption share, or None, if the ciphertext isn’t valid.