pub struct Signature(/* private fields */);Expand description
A BLS signature.
Signatures are created by signing a message with a SecretKey and can be verified
using the corresponding PublicKey.
Example
use threshold_pairing::{SecretKey, Signature, SIG_SIZE};
let sk = SecretKey::random();
let pk = sk.public_key();
let sig = sk.sign(b"message");
assert!(pk.verify(&sig, b"message"));
// Serialize and deserialize
let bytes: [u8; SIG_SIZE] = sig.to_bytes();
let sig2 = Signature::from_bytes(&bytes).unwrap();
assert_eq!(sig, sig2);Implementations
Sourceimpl Signature
impl Signature
Sourcepub fn from_bytes<B: Borrow<[u8; 96]>>(bytes: B) -> FromBytesResult<Self>
pub fn from_bytes<B: Borrow<[u8; 96]>>(bytes: B) -> FromBytesResult<Self>
Returns the signature with the given representation, if valid.
The from_compressed method performs full validation including subgroup
checks to prevent small subgroup attacks.
Errors
Returns FromBytesError::Invalid if:
- The bytes do not represent a valid compressed G2 point
- The point is not on the curve
- The point is not in the correct subgroup
Example
use threshold_pairing::{SecretKey, Signature, SIG_SIZE};
let sk = SecretKey::random();
let sig = sk.sign(b"message");
// Round-trip through bytes
let bytes: [u8; SIG_SIZE] = sig.to_bytes();
let sig2 = Signature::from_bytes(&bytes).expect("valid bytes");
assert_eq!(sig, sig2);Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Signature
impl<'de> Deserialize<'de> for Signature
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Distribution<Signature> for Standard
impl Distribution<Signature> for Standard
Sourceimpl Ord for Signature
impl Ord for Signature
Sourceimpl PartialOrd for Signature
impl PartialOrd for Signature
Sourceimpl TryFrom<&[u8; 96]> for Signature
impl TryFrom<&[u8; 96]> for Signature
Sourcetype Error = FromBytesError
type Error = FromBytesError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<[u8; 96]> for Signature
impl TryFrom<[u8; 96]> for Signature
Sourcetype Error = FromBytesError
type Error = FromBytesError
The type returned in the event of a conversion error.
impl Eq for Signature
impl StructuralPartialEq for Signature