SerdeSecret

Struct SerdeSecret 

pub struct SerdeSecret<T>(pub T);
SerdeSecret is a wrapper struct for serializing and deserializing secret keys. Due to security concerns serialize shouldn’t be implemented for secret keys to avoid accidental leakage.

Whenever this struct is used the integrity of security boundaries should be checked carefully.

Tuple Fields

0: T

Implementations

Source

impl<T> SerdeSecret<T>

pub fn into_inner(self) -> T

Returns the actual secret from the wrapper

pub fn inner(&self) -> &T

Returns a reference to the actual secret contained in the wrapper